ConsumerOffsetClient

Trait ConsumerOffsetClient 

pub trait ConsumerOffsetClient {
    // Required methods
    fn store_consumer_offset<'life0, 'life1, 'life2, 'life3, 'async_trait>(
        &'life0 self,
        consumer: &'life1 Consumer,
        stream_id: &'life2 Identifier,
        topic_id: &'life3 Identifier,
        partition_id: Option<u32>,
        offset: u64,
    ) -> Pin<Box<dyn Future<Output = Result<(), IggyError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait;
    fn get_consumer_offset<'life0, 'life1, 'life2, 'life3, 'async_trait>(
        &'life0 self,
        consumer: &'life1 Consumer,
        stream_id: &'life2 Identifier,
        topic_id: &'life3 Identifier,
        partition_id: Option<u32>,
    ) -> Pin<Box<dyn Future<Output = Result<Option<ConsumerOffsetInfo>, IggyError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait;
    fn delete_consumer_offset<'life0, 'life1, 'life2, 'life3, 'async_trait>(
        &'life0 self,
        consumer: &'life1 Consumer,
        stream_id: &'life2 Identifier,
        topic_id: &'life3 Identifier,
        partition_id: Option<u32>,
    ) -> Pin<Box<dyn Future<Output = Result<(), IggyError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait;
}
This trait defines the methods to interact with the consumer offset module.

Required Methods

fn store_consumer_offset<'life0, 'life1, 'life2, 'life3, 'async_trait>( &'life0 self, consumer: &'life1 Consumer, stream_id: &'life2 Identifier, topic_id: &'life3 Identifier, partition_id: Option<u32>, offset: u64, ) -> Pin<Box<dyn Future<Output = Result<(), IggyError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait,

Store the consumer offset for a specific consumer or consumer group for the given stream and topic by unique IDs or names.

Authentication is required, and the permission to poll the messages.

fn get_consumer_offset<'life0, 'life1, 'life2, 'life3, 'async_trait>( &'life0 self, consumer: &'life1 Consumer, stream_id: &'life2 Identifier, topic_id: &'life3 Identifier, partition_id: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<Option<ConsumerOffsetInfo>, IggyError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait,

Get the consumer offset for a specific consumer or consumer group for the given stream and topic by unique IDs or names.

Authentication is required, and the permission to poll the messages.

fn delete_consumer_offset<'life0, 'life1, 'life2, 'life3, 'async_trait>( &'life0 self, consumer: &'life1 Consumer, stream_id: &'life2 Identifier, topic_id: &'life3 Identifier, partition_id: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<(), IggyError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait,

Delete the consumer offset for a specific consumer or consumer group for the given stream and topic by unique IDs or names.

Authentication is required, and the permission to poll the messages.

Implementors